VideoTrim class

Constructors

VideoTrim({required Duration start, required Duration end})
To specify the part of the video to be trimmed.

Properties

duration Duration
no setter
end Duration
Duration where the trim part ends.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Duration
Duration where the trim part starts.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited