VideoWatermark class

Constructors

VideoWatermark({required String sourceVideoPath, String? videoFileName, Watermark? watermark, OutputFormat? outputFormat = OutputFormat.mp4, String? savePath, VideoTrim? videoTrim, ValueSetter<String?>? onSave, ValueSetter<double>? progress})
Creates Watermark in video with the image in local storage
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onSave ValueSetter<String?>?
Callback triggered when the video convertion completed.
final
outputFormat OutputFormat?
OutputFormat Video format for the output (converted) video
final
progress ValueSetter<double>?
Callback with video conversion completion percentage.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savePath String?
Path where the output video to be saved.
final
sourceVideoPath String
Source video to be added with watermark or trimmed.
final
videoFileName String?
Name of the ouput video file without video format.
final
videoTrim VideoTrim?
VideoTrim For specifying the start and end time of the video to be trimmed.
final
watermark Watermark?
Watermark characteristics of watermark image to be added in video.
final

Methods

generateVideo() Future<void>
Genrates video in the output path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited