botomRight property
Aligns the watermark image in the bottom right corner of the video.
Implementation
static WatermarkAlignment botomRight = WatermarkAlignment._(1, 1, 8);
Aligns the watermark image in the bottom right corner of the video.
static WatermarkAlignment botomRight = WatermarkAlignment._(1, 1, 8);