bottomCenter property
Aligns the watermark image in the bottom center of the video.
Implementation
static WatermarkAlignment bottomCenter = WatermarkAlignment._(2, 1, 2);
Aligns the watermark image in the bottom center of the video.
static WatermarkAlignment bottomCenter = WatermarkAlignment._(2, 1, 2);