topCenter property
Aligns the watermark image in the top center of the video.
Implementation
static WatermarkAlignment topCenter = WatermarkAlignment._(2, 0, 1);
Aligns the watermark image in the top center of the video.
static WatermarkAlignment topCenter = WatermarkAlignment._(2, 0, 1);