topLeft property
Aligns the watermark image in the top left corner of the video.
Implementation
static WatermarkAlignment topLeft = WatermarkAlignment._(0, 0, 6);
Aligns the watermark image in the top left corner of the video.
static WatermarkAlignment topLeft = WatermarkAlignment._(0, 0, 6);