topRight property
Aligns the watermark image in the top right corner of the video.
Implementation
static WatermarkAlignment topRight = WatermarkAlignment._(1, 0, 5);
Aligns the watermark image in the top right corner of the video.
static WatermarkAlignment topRight = WatermarkAlignment._(1, 0, 5);