WatermarkSource class
Add images from various sources in video as overlay using WatermarkSource.
Constructors
- WatermarkSource.asset(String path)
- To add image from assets with asset's path.
- WatermarkSource.file(String path)
- To add image from local storage with file's path
- WatermarkSource.network(String url)
- To add image from network with image url.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCommand(
) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited